# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-04-25 09:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_skill', '0002_auto_20190116_0919'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='skill',
            options={},
        ),
    ]
